## Geographical Set Generator

Write comma-separated names of countries, regions and areas in the inputs below.
Connect countries to regions, and regions to areas by clicking the respective boxes below
Beware not to resize the window after you have started connecting nodes, or the lines may look confusing.. Scrolling is ok however.

Countries

Regions

Areas

Press button to generate corresponding .inc files for CCC, RRR, AAA and connections
Save to folder: